exceptions.Exception

Module exceptions :: Class Exception |
[frames | no frames]

## Type Exception

       object --+
                |
    BaseException --+
                    |
                   Exception

Known Subclasses:
  `ParseBaseException`, `RecursiveGrammarException`

Common base class for all non-exit exceptions.

Method Summary
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
Inherited from `BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Class Variable Summary
Inherited from `BaseException`: `args`, `message`

Method Details

### __init__(...) (Constructor) x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: `exceptions.BaseException.__init__`

    ### __new__(T, S, ...) T.__new__(S, ...) -> a new object with type S, a subtype of T Returns:
        a new object with type S, a subtype of T
Overrides: `exceptions.BaseException.__new__`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net